@@ -9,8 +9,11 @@ EditProviderDialog::EditProviderDialog(QWidget *parent, SearchProvider *provider
 {
     ui->setupUi(this);
     if(provider != NULL) {
+        setWindowTitle("Edit Search Provider");
         ui->txtName->setText(provider->name);
         ui->txtAddress->setText(provider->baseUri);
+    } else {
+        setWindowTitle("Add Search Provider");
     }
 }
 
